@@ -49,23 +49,26 @@ if not cherrypy.__version__.startswith("3.2"):
 from cherrypy import _cpserver
 from cherrypy import _cpwsgi_server
 
+SQLITE_DLL = True
 try:
     from sqlite3 import version as sqlite3_version
 except:
     try:
         from pysqlite2.dbapi2 import version as sqlite3_version
     except:
-        print "Sorry, requires Python module sqlite3 (pysqlite2 in python2.4)"
         if os.name != 'nt':
+            print "Sorry, requires Python module sqlite3 (pysqlite2 in python2.4)"
             print "Try: apt-get install python-pysqlite2"
-        sys.exit(1)
+            sys.exit(1)
+        else:
+            SQLITE_DLL = False
 
 import sabnzbd
 import sabnzbd.interface
 from sabnzbd.constants import *
 import sabnzbd.newsunpack
 from sabnzbd.misc import get_user_shellfolders, launch_a_browser, real_path, \
-     check_latest_version, panic_tmpl, panic_port, panic_fwall, panic, exit_sab, \
+     check_latest_version, panic_tmpl, panic_port, panic_fwall, panic_sqlite, panic, exit_sab, \
      panic_xport, notify, split_host, convert_version, get_ext, create_https_certificates, \
      windows_variant, ip_extract
 import sabnzbd.scheduler as scheduler
@@ -190,6 +193,7 @@ def print_help():
     print "  -c  --clean              Remove queue, cache and logs"
     print "  -p  --pause              Start in paused mode"
     print "      --https <port>       Port to use for HTTPS server"
+    print "      --log-all            Log all article handling (for developers)"
 
 def print_version():
     print """
@@ -356,17 +360,21 @@ def GetProfileInfo(vista_plus):
                 pass
 
     elif sabnzbd.DARWIN:
-        sabnzbd.DIR_APPDATA = '%s/Library/Application Support/SABnzbd' % (os.environ['HOME'])
-        sabnzbd.DIR_LCLDATA = sabnzbd.DIR_APPDATA
-        sabnzbd.DIR_HOME = os.environ['HOME']
-        ok = True
+        home = os.environ.get('HOME')
+        if home:
+            sabnzbd.DIR_APPDATA = '%s/Library/Application Support/SABnzbd' % home
+            sabnzbd.DIR_LCLDATA = sabnzbd.DIR_APPDATA
+            sabnzbd.DIR_HOME = home
+            ok = True
 
     else:
         # Unix/Linux
-        sabnzbd.DIR_APPDATA = '%s/.%s' % (os.environ['HOME'], DEF_WORKDIR)
-        sabnzbd.DIR_LCLDATA = sabnzbd.DIR_APPDATA
-        sabnzbd.DIR_HOME = os.environ['HOME']
-        ok = True
+        home = os.environ.get('HOME')
+        if home:
+            sabnzbd.DIR_APPDATA = '%s/.%s' % (home, DEF_WORKDIR)
+            sabnzbd.DIR_LCLDATA = sabnzbd.DIR_APPDATA
+            sabnzbd.DIR_HOME = home
+            ok = True
 
     if not ok:
         panic("Cannot access the user profile.",
@@ -441,7 +449,7 @@ def get_webhost(cherryhost, cherryport, https_port):
         cherryhost = '0.0.0.0'
         info = socket.getaddrinfo(localhost, None)
     for item in info:
-        ip = item[4][0]
+        ip = str(item[4][0])
         if ip.startswith('169.254.'):
             pass # Is an APIPA
         elif ':' in ip:
@@ -493,10 +501,13 @@ def get_webhost(cherryhost, cherryport, https_port):
 
     # Some systems don't like brackets in numerical ipv6
     if '[' in cherryhost:
-        try:
-            info = socket.getaddrinfo(cherryhost, None)
-        except:
+        if sabnzbd.DARWIN:
             cherryhost = cherryhost.strip('[]')
+        else:
+            try:
+                info = socket.getaddrinfo(cherryhost, None)
+            except:
+                cherryhost = cherryhost.strip('[]')
 
     if ipv6 and ipv4 and \
        (browserhost not in ('localhost', '127.0.0.1', '[::1]', '::1')):
@@ -514,6 +525,10 @@ def get_webhost(cherryhost, cherryport, https_port):
             if ips[0] != '127.0.0.1':
                 browserhost = '127.0.0.1'
 
+    if cherryhost == 'localhost' and sabnzbd.DARWIN:
+        cherryhost = '127.0.0.1'
+        browserhost = 'localhost'
+
     if cherryport is None:
         cherryport = sabnzbd.cfg.CHERRYPORT.get_int()
     else:
@@ -528,7 +543,9 @@ def get_webhost(cherryhost, cherryport, https_port):
 
     if cherryport == https_port:
         sabnzbd.cfg.ENABLE_HTTPS.set(False)
-        logging.error(Ta('error-sameHTTP-HTTPS'))
+        # Should have a translated message, but that's not available yet
+        #logging.error(Ta('error-sameHTTP-HTTPS'))
+        logging.error('HTTP and HTTPS ports cannot be the same')
 
     return cherryhost, cherryport, browserhost, https_port
 
@@ -545,15 +562,16 @@ def is_sabnzbd_running(url):
     except:
         return False
 
-def find_free_port(host, currentport, i=0):
-    while i >=10 and currentport <= 49151:
+def find_free_port(host, currentport):
+    n = 0
+    while n < 10 and currentport <= 49151:
         try:
             cherrypy.process.servers.check_port(host, currentport)
             return currentport
         except:
-            currentport+=5
-            i+=1
-    return -1
+            currentport += 5
+            n += 1
+    return 0
 
 def check_for_sabnzbd(url, upload_nzbs):
     # Check for a running instance of sabnzbd(same version) on this port
@@ -700,7 +718,7 @@ def main():
             slice = 1
         opts, args = getopt.getopt(sys.argv[slice:], "phdvncw:l:s:f:t:b:2:",
                                    ['pause', 'help', 'daemon', 'nobrowser', 'clean', 'logging=',
-                                    'weblogging=', 'server=', 'templates',
+                                    'weblogging=', 'server=', 'templates', 'log-all',
                                     'template2', 'browser=', 'config-file=', 'delay=', 'force',
                                     'version', 'https=', 'autorestarted'])
     except getopt.GetoptError:
@@ -790,11 +808,17 @@ def main():
             https_port = int(arg)
             re_argv.append(opt)
             re_argv.append(arg)
+        elif opt in ('--log-all',):
+            sabnzbd.LOG_ALL = True
 
     # Detect Windows variant
     if sabnzbd.WIN32:
         vista_plus, vista64 = windows_variant()
 
+    if not SQLITE_DLL:
+        panic_sqlite(sabnzbd.MY_FULLNAME)
+        exit_sab(2)
+
     if inifile:
         # INI file given, simplest case
         inifile = evaluate_inipath(inifile)
@@ -852,7 +876,7 @@ def main():
                     port = find_free_port(browserhost, https_port)
                     if port > 0:
                         sabnzbd.cfg.HTTPS_PORT.set(port)
-                        cherryport = port
+                        https_port = port
     ## NonSSL
     try:
         cherrypy.process.servers.check_port(browserhost, cherryport)
@@ -890,6 +914,10 @@ def main():
             if RSS_FILE_NAME not in x:
                 os.remove(x)
 
+    # Prevent the logger from raising exceptions
+    # primarily to reduce the fallout of Python issue 4749
+    logging.raiseExceptions = 0
+
     try:
         sabnzbd.LOGFILE = os.path.join(logdir, DEF_LOG_FILE)
         logsize = sabnzbd.cfg.LOG_SIZE.get_int()
@@ -1121,7 +1149,8 @@ def main():
                 exit_sab(2)
         else:
             logging.debug("Failed to start web-interface: ", exc_info = True)
-            Bail_Out(browserhost, cherryport)
+            # When error 13 occurs, we have no access rights
+            Bail_Out(browserhost, cherryport, '13' in str(error))
     except socket.error, error:
         logging.debug("Failed to start web-interface: ", exc_info = True)
         Bail_Out(browserhost, cherryport, access=True)
