@@ -104,7 +104,7 @@ NEWZBIN_HTTPS = OptionBool('newzbin', 'https', True)
 TOP_ONLY = OptionBool('misc', 'top_only', True)
 AUTODISCONNECT = OptionBool('misc', 'auto_disconnect', True)
 queue_complete = OptionStr('misc', 'queue_complete')
-queue_complete_pers = OptionBool('misc', 'queue_complete_pers', True)
+queue_complete_pers = OptionBool('misc', 'queue_complete_pers', False)
 
 REPLACE_SPACES = OptionBool('misc', 'replace_spaces', False)
 REPLACE_DOTS = OptionBool('misc', 'replace_dots', False)
@@ -165,6 +165,7 @@ else:
 
 USERNAME = OptionStr('misc', 'username')
 PASSWORD = OptionPassword('misc', 'password')
+login_realm = OptionStr('misc', 'login_realm', 'SABnzbd')
 BANDWIDTH_LIMIT = OptionNumber('misc', 'bandwidth_limit', 0)
 REFRESH_RATE = OptionNumber('misc', 'refresh_rate', 0)
 RSS_RATE = OptionNumber('misc', 'rss_rate', 60, 15, 24*60)
@@ -196,6 +197,7 @@ DEBUG_DELAY = OptionNumber('misc', 'debug_delay', 0, add=False)
 
 API_KEY = OptionStr('misc','api_key', create_api_key())
 DISABLE_KEY = OptionBool('misc', 'disable_api_key', False)
+API_WARNINGS = OptionBool('misc', 'api_warnings', True)
 
 #------------------------------------------------------------------------------
 # Set root folders for Folder config-items
