@@ -193,6 +193,24 @@ class LatinFilter(Filter):
             return unicode(str(val))
 
 
+class EmailFilter(Filter):
+    """ Make sure Cheetah gets only Unicode strings
+        Special version to support UTF-8 encoded email templates
+    """
+    def filter(self, val, str=str, **kw):
+        if isinstance(val, unicode):
+            return val
+        elif isinstance(val, basestring):
+            try:
+                return val.decode('utf-8')
+            except:
+                return val.decode('latin-1', 'replace')
+        elif val is None:
+            return u''
+        else:
+            return unicode(str(val))
+
+
 ################################################################################
 #
 # Map CodePage-850 characters to Python's pseudo-Unicode 8bit ASCII
