@@ -1,16 +1,16 @@
 #!/usr/bin/python -OO
-# Copyright 2008 The SABnzbd-Team <team@sabnzbd.org>
+# Copyright 2008-2009 The SABnzbd-Team <team@sabnzbd.org>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
@@ -18,6 +18,11 @@
 ################################################################################
 # Decorators                                                                   #
 ################################################################################
+from threading import RLock, Condition
+
+NZBQUEUE_LOCK = RLock()
+CV = Condition(NZBQUEUE_LOCK)
+
 def synchronized(lock):
     def wrap(f):
         def newFunction(*args, **kw):
@@ -28,3 +33,15 @@ def synchronized(lock):
                 lock.release()
         return newFunction
     return wrap
+
+
+def synchronized_CV(func):
+    global CV
+    def call_func(*params, **kparams):
+        CV.acquire()
+        try:
+            return func(*params, **kparams)
+        finally:
+            CV.notifyAll()
+            CV.release()
+    return call_func
