@@ -114,7 +114,7 @@ def ProcessArchiveFile(filename, path, pp=None, script=None, cat=None, catdir=No
 
     filename, cat = name_to_cat(filename, catdir)
 
-    if path.lower().endswith('.zip'):
+    if zipfile.is_zipfile(path):
         try:
             zf = zipfile.ZipFile(path)
         except:
@@ -169,7 +169,8 @@ def ProcessArchiveFile(filename, path, pp=None, script=None, cat=None, catdir=No
     return status
 
 
-def ProcessSingleFile(filename, path, pp=None, script=None, cat=None, catdir=None, keep=False, priority=None, nzbname=None):
+def ProcessSingleFile(filename, path, pp=None, script=None, cat=None, catdir=None, keep=False,
+                      priority=None, nzbname=None, dup_check=True):
     """ Analyse file and create a job from it
         Supports NZB, NZB.GZ and GZ.NZB-in-disguise
         returns: -2==Error/retry, -1==Error, 0==OK, 1==OK-but-ignorecannot-delete
@@ -204,7 +205,7 @@ def ProcessSingleFile(filename, path, pp=None, script=None, cat=None, catdir=Non
         name = misc.sanitize_foldername(name)
 
     try:
-        nzo = nzbstuff.NzbObject(name, 0, pp, script, data, cat=cat, priority=priority, nzbname=nzbname)
+        nzo = nzbstuff.NzbObject(name, 0, pp, script, data, cat=cat, priority=priority, nzbname=nzbname, dup_check=dup_check)
     except TypeError:
         # Duplicate, ignore
         nzo = None
