@@ -30,7 +30,7 @@ import glob
 from sabnzbd.constants import *
 import sabnzbd
 from sabnzbd.misc import to_units, split_host
-from sabnzbd.codecs import LatinFilter
+from sabnzbd.codecs import EmailFilter
 import sabnzbd.cfg as cfg
 from sabnzbd.lang import T, Ta
 
@@ -166,7 +166,7 @@ def endjob(filename, msgid, cat, status, path, bytes, stages, script, script_out
             source = _decode_file(temp)
             message = Template(source=source,
                                 searchList=[parm],
-                                filter=LatinFilter,
+                                filter=EmailFilter,
                                 compilerSettings={'directiveStartToken': '<!--#',
                                                   'directiveEndToken': '#-->'})
             ret = send(message.respond())
