@@ -95,7 +95,7 @@ def cat_to_opts(cat, pp=None, script=None, priority=None):
             # Get the default priority
             if priority == DEFAULT_PRIORITY:
                 priority = cfg.DIRSCAN_PRIORITY.get()
-            logging.debug('Job gets priority %s', script)
+            logging.debug('Job gets priority %s', priority)
         except KeyError:
             priority = cfg.DIRSCAN_PRIORITY.get()
 
@@ -144,6 +144,7 @@ def CatConvert(cat):
             except:
                 newzbin = []
             for name in newzbin:
+                name = name.strip()
                 if re.search('^%s$' % wildcard_to_re(name), cat, re.I):
                     if '.' not in name:
                         logging.debug('Convert index site category "%s" to user-cat "%s"', cat, ucat)
@@ -172,8 +173,9 @@ def CatConvert(cat):
 # sanitize_filename                                                            #
 ################################################################################
 if sabnzbd.WIN32:
-    CH_ILLEGAL = r'\/<>?*:|"'
-    CH_LEGAL   = r'++{}!@-#`'
+    # the colon should be here too, but we'll handle that separately
+    CH_ILLEGAL = r'\/<>?*|"'
+    CH_LEGAL   = r'++{}!@#`'
 else:
     CH_ILLEGAL = r'/'
     CH_LEGAL   = r'+'
@@ -182,9 +184,19 @@ def sanitize_filename(name):
     """ Return filename with illegal chars converted to legal ones
         and with the par2 extension always in lowercase
     """
+    if not name:
+        return name
     illegal = CH_ILLEGAL
     legal   = CH_LEGAL
 
+    if ':' in name:
+        if sabnzbd.WIN32:
+            # Compensate for the odd way par2 on Windows substitutes a colon character
+            name = name.replace(':', '3A')
+        elif sabnzbd.DARWIN:
+            # Compensate for the foolish way par2 on OSX handles a colon character
+            name = name[name.rfind(':')+1:]
+
     lst = []
     for ch in name.strip():
         if ch in illegal:
@@ -210,6 +222,8 @@ def sanitize_foldername(name):
     """ Return foldername with dodgy chars converted to safe ones
         Remove any leading and trailing dot and space characters
     """
+    if not name:
+        return name
     if isinstance(name, unicode):
         illegal = uFL_ILLEGAL
         legal   = uFL_LEGAL
@@ -653,6 +667,7 @@ def check_latest_version():
         f = open(fn, 'r')
         data = f.read()
         f.close()
+        os.remove(fn)
     except:
         return
 
