@@ -458,6 +458,7 @@ def RAR_Extract(rarfile, numrars, nzo, setname, extraction_path):
 
     stup, need_shell, command, creationflags = build_command(command)
 
+    logging.debug("Running unrar %s", command)
     p = subprocess.Popen(command, shell=need_shell, stdin=subprocess.PIPE,
                          stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
                          startupinfo=stup, creationflags=creationflags)
@@ -826,7 +827,12 @@ def PAR_Verify(parfile, parfile_nzf, nzo, setname, joinables, classic=False):
                 continue
 
             # And off we go
-            if line.startswith('All files are correct'):
+            if line.startswith('Invalid option specified'):
+                msg = T('msg-badppar@1') % unicoder(setname)
+                nzo.set_unpack_info('Repair', msg, set=setname)
+                nzo.status = 'Failed'
+
+            elif line.startswith('All files are correct'):
                 msg = T('msg-verifyOK@2') % (unicoder(setname), format_time_string(time() - start))
                 nzo.set_unpack_info('Repair', msg, set=setname)
                 logging.info('Verified in %s, all files correct',
