@@ -316,7 +316,9 @@ class NzbQueue(TryList):
         if nzo_id in self.__nzo_table:
             nzo = self.__nzo_table[nzo_id]
             nzo.resume_nzo()
+            nzo.reset_all_try_lists()
             logging.debug("Resumed nzo: %s", nzo_id)
+        self.reset_try_list()
 
     @synchronized(NZBQUEUE_LOCK)
     def switch(self, item_id_1, item_id_2):
@@ -538,7 +540,7 @@ class NzbQueue(TryList):
         ''' Check if the queue contains any Forced
         Priority items to download while paused '''
         for nzo in self.__nzo_list:
-            if nzo.get_priority() == TOP_PRIORITY and nzo.get_status() != 'Paused':
+            if nzo.get_priority() == TOP_PRIORITY and nzo.get_status() not in ('Paused', 'Grabbing'):
                 return True
         return False
 
@@ -547,7 +549,7 @@ class NzbQueue(TryList):
         if self.__top_only:
             if self.__nzo_list:
                 for nzo in self.__nzo_list:
-                    if not nzo.get_status() == 'Paused':
+                    if nzo.get_status() not in ('Paused', 'Grabbing'):
                         article = nzo.get_article(server)
                         if article:
                             return article
@@ -555,7 +557,7 @@ class NzbQueue(TryList):
         else:
             for nzo in self.__nzo_list:
                 # Don't try to get an article if server is in try_list of nzo
-                if not nzo.server_in_try_list(server) and nzo.get_status() != 'Paused':
+                if not nzo.server_in_try_list(server) and nzo.get_status() not in ('Paused', 'Grabbing'):
                     article = nzo.get_article(server)
                     if article:
                         return article
