@@ -39,7 +39,7 @@ import sabnzbd.config as config
 import sabnzbd.cfg as cfg
 from sabnzbd.trylist import TryList
 from sabnzbd.lang import T, Ta
-from sabnzbd.misc import to_units, cat_to_opts, CatConvert
+from sabnzbd.misc import to_units, cat_to_opts, CatConvert, sanitize_foldername
 from sabnzbd.codecs import unicoder, platform_encode
 
 RE_NEWZBIN = re.compile(r"msgid_(\w+) (.+)(\.nzb)$", re.I)
@@ -431,11 +431,13 @@ class NzbParser(xml.sax.handler.ContentHandler):
 class NzbObject(TryList):
     def __init__(self, filename, msgid, pp, script, nzb = None,
                  futuretype = False, cat = None, url=None,
-                 priority=NORMAL_PRIORITY, nzbname=None, status="Queued", nzo_info=None):
+                 priority=NORMAL_PRIORITY, nzbname=None, status="Queued", nzo_info=None,
+                 dup_check=False):
         TryList.__init__(self)
 
         filename = platform_encode(filename)
         nzbname = platform_encode(nzbname)
+        nzbname = sanitize_foldername(nzbname)
 
         if pp is None:
             r = u = d = None
@@ -453,7 +455,7 @@ class NzbObject(TryList):
             dname, ext = os.path.splitext(dirname) # Used for folder name for final unpack
             if ext.lower() == '.nzb':
                 dirname = dname
-            dirname = sabnzbd.misc.sanitize_foldername(dirname)
+            dirname = sanitize_foldername(dirname)
         dirname, password = scan_password(dirname)
 
         self.__dirname = dirname      # Keeps track of the working folder
@@ -547,7 +549,7 @@ class NzbObject(TryList):
             logging.info('Replacing spaces with underscores in %s', self.__dirname)
             self.__original_dirname = self.__original_dirname.replace(' ','_')
 
-        if sabnzbd.backup_exists(filename):
+        if dup_check and sabnzbd.backup_exists(filename):
             # File already exists and we have no_dupes set
             logging.warning(Ta('warn-skipDup@1'), filename)
             raise TypeError
@@ -741,7 +743,7 @@ class NzbObject(TryList):
     def set_name(self, name):
         if isinstance(name, str):
             name, self.extra2 = scan_password(platform_encode(name))
-            self.__original_dirname = sabnzbd.misc.sanitize_foldername(name)
+            self.__original_dirname = sanitize_foldername(name)
             return True
         return False
 
