@@ -394,7 +394,7 @@ class PostProcessor(Thread):
                             if script_log:
                                 fname = nzo.get_nzo_id()
                             if script_line:
-                                nzo.set_unpack_info('Script', script_line, unique=True)
+                                nzo.set_unpack_info('Script', unicoder(script_line), unique=True)
                             else:
                                 nzo.set_unpack_info('Script', T('msg-ranScript@1') % unicoder(script), unique=True)
                     else:
@@ -415,9 +415,13 @@ class PostProcessor(Thread):
                         else:
                             script_ret = ''
                         if script_line:
-                            nzo.set_unpack_info('Script','%s%s <a href="./scriptlog?name=%s">(%s)</a>' % (script_ret, script_line, urllib.quote(fname), T('link-more')), unique=True)
+                            nzo.set_unpack_info(u'Script','%s%s <a href="./scriptlog?name=%s">(%s)</a>' % (script_ret, unicoder(script_line), urllib.quote(fname), T('link-more')), unique=True)
                         else:
-                            nzo.set_unpack_info('Script','%s<a href="./scriptlog?name=%s">%s</a>' % (script_ret, urllib.quote(fname), T('link-viewSc')), unique=True)
+                            nzo.set_unpack_info(u'Script','%s<a href="./scriptlog?name=%s">%s</a>' % (script_ret, urllib.quote(fname), T('link-viewSc')), unique=True)
+
+
+                ## Cleanup again, including NZB files
+                CleanUpList(workdir_complete, False)
 
                 ## Remove newzbin bookmark, if any
                 if msgid:
@@ -619,10 +623,9 @@ def NzbRedirect(wdir, pp, script, cat, priority):
             return list
 
     # Process all NZB files
-    keep = not on_cleanup_list("x.nzb", False)
     for file in files:
         if file.lower().endswith('.nzb'):
-            dirscanner.ProcessSingleFile(file, os.path.join(wdir, file), pp, script, cat, priority=priority, keep=keep)
+            dirscanner.ProcessSingleFile(file, os.path.join(wdir, file), pp, script, cat, priority=priority, keep=False, dup_check=False)
             list.append(file)
 
     return list
