@@ -162,7 +162,6 @@ class RSSQueue:
         #           order : order in the RSS feed
 
         self.shutdown = False
-        self.__running = False
 
     def stop(self):
         self.shutdown = True
@@ -286,16 +285,16 @@ class RSSQueue:
                     logging.info("Ignoring duplicate job %s", atitle)
                     continue
 
-                myCat = defCat
-                myPP = ''
-                myScript = ''
-                #myPriority = 0
-
                 if (link not in jobs) or (jobs[link].get('status', ' ') in ('G', 'B', 'G*', 'B*')):
                     # Match this title against all filters
                     logging.debug('Trying title %s', atitle)
                     result = False
                     for n in xrange(regcount):
+                        myCat = defCat
+                        myPP = ''
+                        myScript = ''
+                        #myPriority = 0
+
                         if notdefault(reCats[n]):
                             myCat = reCats[n]
                         elif category:
@@ -369,30 +368,30 @@ class RSSQueue:
 
         return ''
 
+
     def run(self):
         """ Run all the URI's and filters """
-        # Protect against second scheduler call before current
-        # run is completed. Cannot use LOCK, because run_feed
-        # already uses the LOCK.
 
-        if not (self.__running or sabnzbd.PAUSED_ALL):
-            self.__running = True
+        if not sabnzbd.PAUSED_ALL:
+            logging.info('Running scheduled RSS scan')
             active = False
             feeds = config.get_rss()
-            for feed in feeds:
-                if feeds[feed].enable.get():
-                    active = True
-                    self.run_feed(feed, download=True, ignoreFirst=True)
-                    # Wait 30 seconds, else sites may get irritated
-                    for x in xrange(30):
-                        if self.shutdown:
-                            self.__running = False
-                            return
-                        else:
-                            time.sleep(1.0)
+            for feed in feeds.keys():
+                try:
+                    if feeds[feed].enable.get():
+                        active = True
+                        self.run_feed(feed, download=True, ignoreFirst=True)
+                        # Wait 15 seconds, else sites may get irritated
+                        for x in xrange(15):
+                            if self.shutdown:
+                                return
+                            else:
+                                time.sleep(1.0)
+                except KeyError:
+                    # Feed must have been deleted
+                    pass
             if active:
                 self.save()
-            self.__running = False
 
 
     @synchronized(LOCK)
