@@ -233,11 +233,10 @@ def _matrix_url(url):
         if not _RE_NZBMATRIX_USER.search(url) or not _RE_NZBMATRIX_API.search(url):
             user = urllib.quote_plus(cfg.MATRIX_USERNAME.get())
             key = urllib.quote_plus(cfg.MATRIX_APIKEY.get())
-            url = '%s://nzbmatrix.com/api-nzb-download.php?id=%s&username=%s&apikey=%s' % \
+            url = '%s://api.nzbmatrix.com/v1.1/download.php?id=%s&username=%s&apikey=%s' % \
                   (_PROTOCOL, matrix_id, user, key)
     return url, matrix_id
 
-
 _RE_MATRIX_ERR = re.compile(r'please_wait[_ ]+(\d+)', re.I)
 
 def _analyse_matrix(fn, matrix_id):
